@@ -25,11 +25,13 @@
 #include "e-categories-master-list-array.h"
 
 #include <gal/util/e-i18n.h>
+#include <gal/util/e-util.h>
 #include <gal/util/e-xml-utils.h>
 #include <libxml/tree.h>
 #include <libxml/parser.h>
 #include <libxml/xmlmemory.h>
 #include "e-unicode.h"
+#include <stdlib.h>
 #include <string.h>
 
 #define PARENT_TYPE e_categories_master_list_get_type ()
@@ -38,7 +40,7 @@
 
 typedef enum {
 	E_CATEGORIES_MASTER_LIST_ARRAY_NORMAL,
-	E_CATEGORIES_MASTER_LIST_ARRAY_DELETED,
+	E_CATEGORIES_MASTER_LIST_ARRAY_DELETED
 } ECategoriesMasterListArrayState;
 
 typedef struct {
@@ -301,9 +303,8 @@ ecmla_default (ECategoriesMasterListArray *ecmla)
 	ecmla->priv->categories = g_new (ECategoriesMasterListArrayItem *, BUILTIN_CATEGORY_COUNT);
 
 	for (i = 0; i < BUILTIN_CATEGORY_COUNT; i++) {
-		char *category = e_utf8_from_locale_string(_(builtin_categories[i].category));
+		char *category = _(builtin_categories[i].category);
 		ecmla->priv->categories[i] = ecmlai_new (category, builtin_categories[i].icon, NULL);
-		g_free (category);
 	}
 }
 
@@ -321,7 +322,7 @@ ecmla_reset (ECategoriesMasterList *ecml)
 }
 
 static void
-ecmla_destroy (GtkObject *object)
+ecmla_dispose (GObject *object)
 {
 	ECategoriesMasterListArray *ecmla = E_CATEGORIES_MASTER_LIST_ARRAY (object);
 
@@ -329,17 +330,17 @@ ecmla_destroy (GtkObject *object)
 	g_free (ecmla->priv);
 	ecmla->priv = NULL;
 
-	if (GTK_OBJECT_CLASS (parent_class)->destroy)
-		(* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
+	if (G_OBJECT_CLASS (parent_class)->dispose)
+		(* G_OBJECT_CLASS (parent_class)->dispose) (object);
 }
 
 
 static void
-ecmla_class_init (GtkObjectClass *object_class)
+ecmla_class_init (GObjectClass *object_class)
 {
 	ECategoriesMasterListClass *ecml_class = E_CATEGORIES_MASTER_LIST_CLASS(object_class);
 
-	parent_class          = gtk_type_class (PARENT_TYPE);
+	parent_class          = g_type_class_ref (PARENT_TYPE);
 
 	ecml_class->count     = ecmla_count    ;
 	ecml_class->nth       = ecmla_nth      ;
@@ -351,7 +352,7 @@ ecmla_class_init (GtkObjectClass *object_class)
 
 	ecml_class->reset     = ecmla_reset    ;
 
-	object_class->destroy = ecmla_destroy  ;
+	object_class->dispose = ecmla_dispose  ;
 }
 
 static void
@@ -367,33 +368,17 @@ ecmla_init (ECategoriesMasterListArray *ecmla)
 	ecmla_default (ecmla);
 }
 
-GtkType
-e_categories_master_list_array_get_type (void)
-{
-	static guint type = 0;
-	
-	if (!type) {
-		GtkTypeInfo info = {
-			"ECategoriesMasterListArray",
-			sizeof (ECategoriesMasterListArray),
-			sizeof (ECategoriesMasterListArrayClass),
-			(GtkClassInitFunc) ecmla_class_init,
-			(GtkObjectInitFunc) ecmla_init,
-			/* reserved_1 */ NULL,
-			/* reserved_2 */ NULL,
-			(GtkClassInitFunc) NULL,
-		};
-
-		type = gtk_type_unique (PARENT_TYPE, &info);
-	}
-
-	return type;
-}
+E_MAKE_TYPE (e_categories_master_list_array,
+	     "ECategoriesMasterListArray",
+	     ECategoriesMasterListArray,
+	     ecmla_class_init,
+	     ecmla_init,
+	     PARENT_TYPE)
 
 ECategoriesMasterList *
 e_categories_master_list_array_new       (void)
 {
-	return E_CATEGORIES_MASTER_LIST (gtk_type_new (e_categories_master_list_array_get_type ()));
+	return E_CATEGORIES_MASTER_LIST (g_object_new (E_CATEGORIES_MASTER_LIST_ARRAY_TYPE, NULL));
 }
 
 void
